# -*- coding: utf-8 -*-

""" Coworking cowoker testing module """

from datetime import date
from odoo import fields
from odoo.exceptions import ValidationError
from odoo.tests.common import TransactionCase

class TestCoworkingCoworker(TransactionCase):
    """ Coworking cowoker testing """

    def setUp(self, *args, **kwargs):
        """ Bootstrap testing """
        super(TestCoworkingCoworker, self).setUp(*args, **kwargs)
        data = {'name': 'Homer Simpson', 'is_coworker': True}
        self.homer = self.env['res.partner'].create(data)

    def test_contact_date(self):
        """ Test contact date : default to today and validity """
        contact_date = fields.Date.from_string(self.homer.contact_date)
        self.assertEqual(contact_date, date.today())

        marge = self.env['res.partner'].create({'name': 'Marge Simpson',
                                                'contact_date': '2017-01-01'})
        self.assertEqual(marge.contact_date, '2017-01-01')

        with self.assertRaises(ValidationError) as err:
            data = {'name': 'Bart Simpson', 'contact_date': '2999-01-01'}
            self.env['res.partner'].create(data)
        self.assertIn('equal of inferior to', unicode(err.exception))

    def test_full_address(self):
        """ Test full address rendering """
        full_contact_adress = fields.from_string(self.homer.full_contact_adress)
        self.assertEqual(full_contact_adress, {full_contact_adress = u'{} {} {}'.format \
        (street or u'', contact_zip or u'', city or u'').strip()})

        fulladdr = self.env{'street': '29 Grande rue',
                    'contact_zip': '26270',
                    'city': 'Loriol'}

        self.assertEqual(fulladdr.full_contact_adress, '29 Grande rue 26270 Loriol')

        with self.assertRaises(ValidationError) as err:
            fulladdr = {'street': '29 Grande rue',
                        'contact_zip': '26270',
                        'city': 'Loriol'}
            self.env['coworking.coworker'].create(fulladdr)
        self.assertIn('No full address valide', unicode(err.exception))



    def test_manage_coworker_type(self):
        """ Test that non-coworker have not coworker_type fixed """
        pass
